==> ugene_1.12.3%2Bdfsg.orig.tar.xz: ugene-1.12.3+dfsg.orig/src/plugins/GUITestBase/src/tests/common_scenarios/tree_viewer/GTTestsCommonScenariousTreeviewer.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
k
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef GTTESTS_TREE_VIEWER_H_
#define GTTESTS_TREE_VIEWER_H_

#include <U2Test/GUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_tree_viewer {
#undef GUI_TEST_PREFIX
#define GUI_TEST_PREFIX "GUITest_common_scenarios_tree_viewer_"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0001_1)
GUI_TEST_CLASS_DECLARATION(test_0001_2)

GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0002_1)
GUI_TEST_CLASS_DECLARATION(test_0002_2)

GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
//GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0008_1)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0011_1)
GUI_TEST_CLASS_DECLARATION(test_0011_2)
GUI_TEST_CLASS_DECLARATION(test_0012)

#undef GUI_TEST_PREFIX
} // namespace U2

} //namespace
#endif // GTTESTS_TREE_VIEWER_H_

==> ugene_1.19.0%2Bdfsg.orig.tar.xz: ugene-1.19.0/src/plugins/GUITestBase/src/tests/common_scenarios/tree_viewer/GTTestsCommonScenariousTreeviewer.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2015 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
k
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef GTTESTS_TREE_VIEWER_H_
#define GTTESTS_TREE_VIEWER_H_

#include <U2Test/GUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_tree_viewer {
#undef GUI_TEST_PREFIX
#define GUI_TEST_PREFIX "GUITest_common_scenarios_tree_viewer_"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0001_1)
GUI_TEST_CLASS_DECLARATION(test_0001_2)

GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0002_1)
GUI_TEST_CLASS_DECLARATION(test_0002_2)

GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0008_1)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0011_1)
GUI_TEST_CLASS_DECLARATION(test_0011_2)
GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0023)//outdated
GUI_TEST_CLASS_DECLARATION(test_0024)
GUI_TEST_CLASS_DECLARATION(test_0025)
GUI_TEST_CLASS_DECLARATION(test_0026)
GUI_TEST_CLASS_DECLARATION(test_0027)
GUI_TEST_CLASS_DECLARATION(test_0028)
GUI_TEST_CLASS_DECLARATION(test_0029)

#undef GUI_TEST_PREFIX
} // namespace U2

} //namespace
#endif // GTTESTS_TREE_VIEWER_H_
